@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2015 David R. MacIver
+# Most of this work is copyright (C) 2013-2016 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -103,10 +103,9 @@ class Unsatisfiable(HypothesisException):
 
 class Flaky(HypothesisException):
 
-    """
-    This function appears to fail non-deterministically: We have seen it fail
-    when passed this example at least once, but a subsequent invocation did not
-    fail.
+    """This function appears to fail non-deterministically: We have seen it
+    fail when passed this example at least once, but a subsequent invocation
+    did not fail.
 
     Common causes for this problem are:
         1. The function depends on external state. e.g. it uses an external
@@ -117,6 +116,7 @@ class Flaky(HypothesisException):
         3. The function is timing sensitive and can fail or pass depending on
            how long it takes. Try breaking it up into smaller functions which
            dont' do that and testing those instead.
+
     """
 
 
